package com.sxc.etaxincome.controller;

import com.sxc.etaxincome.common.enums.CountTypeCode;
import com.sxc.etaxincome.domain.command.analysis.IAnalysisCommand;
import com.sxc.etaxincome.domain.model.report.AnalysisCriteria;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Slf4j
@RestController
@RequestMapping("/analysis")
public class AnalysisController {


    @Autowired
    @Qualifier(value = "analysisCommand")
    private IAnalysisCommand analysisCommand;
    @Autowired
    @Qualifier(value = "areaGroupCommand")
    private IAnalysisCommand areaGroupCommand;
    @Autowired
    @Qualifier(value = "queryIncomeSuccessAnalysisCommand")
    private IAnalysisCommand queryIncomeSuccessAnalysisCommand;
    @Autowired
    @Qualifier(value = "groupAnalysisCommand")
    private IAnalysisCommand groupAnalysisCommand;
    @Autowired
    @Qualifier(value = "sellerGrowthCommand")
    private IAnalysisCommand sellerGrowthCommand;

    @GetMapping("/hourly")
    public String analysisHourly(AnalysisCriteria analysisCriteria) {
        analysisCriteria.setCountType(CountTypeCode.HOUR.getCode());
        return analysisCommand.handle(analysisCriteria);
    }

    @GetMapping("/daily")
    public String analysisDaily(AnalysisCriteria analysisCriteria) {
        analysisCriteria.setCountType(CountTypeCode.DAY.getCode());
        return analysisCommand.handle(analysisCriteria);
    }

    @GetMapping("/monthly")
    public String analysisMonthly(AnalysisCriteria analysisCriteria) {
        analysisCriteria.setCountType(CountTypeCode.MONTH.getCode());
        return analysisCommand.handle(analysisCriteria);
    }

    @GetMapping("/weekly")
    public String analysisWeekly(AnalysisCriteria analysisCriteria) {
        analysisCriteria.setCountType(CountTypeCode.WEEK.getCode());
        return analysisCommand.handle(analysisCriteria);
    }

    @GetMapping("/area-group")
    public String analysisAreaGroup(AnalysisCriteria analysisCriteria) {
        return areaGroupCommand.handle(analysisCriteria);
    }

    @GetMapping("/query-income-success")
    public String queryIncomeSuccessList(AnalysisCriteria analysisCriteria) {
        return queryIncomeSuccessAnalysisCommand.handle(analysisCriteria);
    }

    @GetMapping("/daily-group")
    public String analysisDailyGroup(AnalysisCriteria analysisCriteria) {
        analysisCriteria.setCountType(CountTypeCode.DAY.getCode());
        return groupAnalysisCommand.handle(analysisCriteria);
    }

    @GetMapping("/seller-growth")
    public String analysisSellerGrowth(AnalysisCriteria analysisCriteria) {
        return sellerGrowthCommand.handle(analysisCriteria);
    }
}
