package com.sxc.etaxincome.domain.business.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.google.common.collect.Lists;
import com.sxc.etaxincome.criteria.FinRealLogCriteria;
import com.sxc.etaxincome.criteria.IncomeQueryCriteria;
import com.sxc.etaxincome.domain.business.IQueryManager;
import com.sxc.etaxincome.domain.constants.CommonConstants;
import com.sxc.etaxincome.domain.model.common.PageList;
import com.sxc.etaxincome.domain.model.report.IncomeCompletePeriod;
import com.sxc.etaxincome.entity.FinRealLog;
import com.sxc.etaxincome.service.IFinRealLogService;
import com.sxc.framework.common.code.EncryptUtil;
import com.sxc.framework.common.json.JSONUtil;
import com.sxc.framework.common.string.StringUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author caosongqing
 * @date 2023/2/10
 * @description
 */
@Slf4j
@Service
public class QueryManager implements IQueryManager {

    @Autowired
    private IFinRealLogService finRealLogService;


    @Override
    public String queryPageListOrderByUpdateTimeDesc(IncomeQueryCriteria incomeQueryCriteria) {
        FinRealLogCriteria finRealLogCriteria = FinRealLogCriteria.builder()
                .userCode(incomeQueryCriteria.getUserCode())
                .zoneCode(incomeQueryCriteria.getZoneCode())
                .taxno(incomeQueryCriteria.getTaxno())
                .itype(incomeQueryCriteria.getItype())
                .reqSign(incomeQueryCriteria.getReqSign())
                .reqContext(incomeQueryCriteria.getReqContext())
                .resContext(incomeQueryCriteria.getResContext())
                .resMsg(incomeQueryCriteria.getResMsg())
                .timeFlag(incomeQueryCriteria.getTimeFlag())
                .resCode(incomeQueryCriteria.getResCode())
                .dateTimeStart(incomeQueryCriteria.getStartDateTime())
                .dateTimeEnd(incomeQueryCriteria.getEndDateTime())
                .startTimeDiff(incomeQueryCriteria.getStartTimeDiff())
                .endTimeDiff(incomeQueryCriteria.getEndTimeDiff())
                .build();
        int start = incomeQueryCriteria.getPageNumber();
        int limit = incomeQueryCriteria.getPageSize();
        IPage<FinRealLog> incomeInvoiceApplyPage = finRealLogService.queryPageListOrderByRequestTimeDesc(finRealLogCriteria, start, limit);
        List<FinRealLog> incomeInvoiceApplyList = incomeInvoiceApplyPage.getRecords();
        PageList<FinRealLog> incomeInvoiceApplyPageList = PageList.<FinRealLog>builder()
                .total(Integer.valueOf(String.valueOf(incomeInvoiceApplyPage.getTotal())))
                .pageNumber(start)
                .pageSize(limit)
                .list(incomeInvoiceApplyList).build();
        return JSONUtil.toString(incomeInvoiceApplyPageList);
    }

    @Override
    public String completePeriod(Long applyId) {
        FinRealLog incomeInvoiceApply = finRealLogService.getBaseMapper().selectById(applyId);
        return this.completePeriod(incomeInvoiceApply);
    }

    @Override
    public String completePeriod(FinRealLog incomeInvoiceApply) {
        JSONObject requestParam = new JSONObject();
        JSONObject cookie = new JSONObject();
        String reqContext = incomeInvoiceApply.getReqContext();
        if (StringUtil.isNotEmpty(reqContext)) {
            if(reqContext.contains("token")) {
                String preReqContext = reqContext.substring(reqContext.indexOf("T1C2K3"));
                String cookieContext = EncryptUtil.decryptAesCk(preReqContext.substring(0, preReqContext.indexOf("\\")));
                if(StringUtil.isNotEmpty(cookieContext)) {
                    cookie = JSON.parseObject(cookieContext);
                    requestParam.put("cookie", cookie.get("cookie"));
                    requestParam.put("dqdm", incomeInvoiceApply.getZoneCode());
                }
            }
        }
        JSONObject responseResult = null;
        IncomeCompletePeriod incomeCompletePeriod = IncomeCompletePeriod.builder()
                .cookie(cookie)
                .requestParam(requestParam)
                .reqContext(incomeInvoiceApply.getReqContext())
                .resContext(incomeInvoiceApply.getResContext())
                .build();
        return JSONUtil.toString(incomeCompletePeriod);
    }


}
