package com.sxc.etaxincome.domain.command.report;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.nacos.api.config.annotation.NacosValue;
import com.google.common.base.Stopwatch;
import com.sxc.etaxincome.common.util.RetryHttpHelper;
import com.sxc.etaxincome.domain.business.IApiConfigManager;
import com.sxc.etaxincome.domain.constants.EtaxReportConstants;
import com.sxc.etaxincome.domain.exception.EtaxIncomeException;
import com.sxc.etaxincome.domain.handler.transferparam.IReportTransferParamHandler;
import com.sxc.etaxincome.domain.model.cookie.TokenNecessary;
import com.sxc.etaxincome.domain.model.report.*;
import com.sxc.etaxincome.domain.model.common.CommonRequestWrapper;
import com.sxc.etaxincome.domain.model.common.CommonResponse;
import com.sxc.etaxincome.domain.template.ResponseHandlerTemplate;
import com.sxc.etaxincome.enums.ApiCode;
import com.sxc.framework.common.httpclient.ResponseContent;
import com.sxc.framework.common.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.concurrent.TimeUnit;

import static com.sxc.etaxincome.domain.constants.EtaxReportConstants.*;

@Slf4j
@Component(value = "generalTaxpayerReportCommand")
public class GeneralTaxpayerReportCommand implements IReportCommand {

    @NacosValue(value = "${url.etax.report}", autoRefreshed = true)
    private String etaxReportUrl;

    @Autowired
    private IApiConfigManager apiConfigManager;

    @Autowired
    private List<IReportTransferParamHandler> reportTransferParamHandlerList;

    @Override
    public CommonResponse<IReportResponse> execute(CommonRequestWrapper commonRequestWrapper) {
        Stopwatch stopwatch = Stopwatch.createStarted();
        ApiConfig apiConfig = apiConfigManager.getApiConfig(ApiCode.REPORT.getCode());
        JSONObject requestDataJsonObject = new JSONObject();
        String requestDataStr = commonRequestWrapper.getData();
        String requestSerialNo = commonRequestWrapper.getRequestSerialNo();
        log.info("report requestSerialNo:{} data:{}", requestSerialNo, requestDataStr);
        ReportRequestWrapper reportRequestWrapper = JSON.parseObject(requestDataStr, ReportRequestWrapper.class);
        TokenNecessary tokenNecessary = reportRequestWrapper.decodeToken();
        String token = tokenNecessary.getToken();
        requestDataJsonObject.put(API_PARAM_TOKEN, token);
        requestDataJsonObject.put(API_PARAM_AREA_CODE, reportRequestWrapper.getArea());
        String test = reportRequestWrapper.getTest();
        if (StringUtils.isNotBlank(test)) {
            requestDataJsonObject.put(API_PARAM_TEST, test);
        }
        reportTransferParamHandlerList.forEach(e -> e.handle(apiConfig, commonRequestWrapper, reportRequestWrapper));
        requestDataJsonObject.put("formData", reportRequestWrapper.getFormData());
        try {
            String etaxReportUrlFull = etaxReportUrl + apiConfig.getApiUrl();
            log.info("url:{}", etaxReportUrlFull);
            String requestJson = JSONUtil.toString(requestDataJsonObject);
            log.info("request:{}", requestJson);
            ResponseContent responseContent = RetryHttpHelper.retryPostJsonEntity(etaxReportUrlFull, requestJson);
            String response = responseContent.getContent();
            log.info("response:{}", response);
            stopwatch.stop();
            log.info("query cancel page list elapsed time:{}ms", stopwatch.elapsed(TimeUnit.MILLISECONDS));
            return new ResponseHandlerTemplate<IReportResponse>() {
                @Override
                public CommonResponse<IReportResponse> handleSuccess(JSONObject jsonObject) {
                    JSONObject resultJsonObject = jsonObject.getJSONObject(EtaxReportConstants.ETAX_RESPONSE_DATA_KEY);
                    ReportResponse reportResponse = new ReportResponse();
                    reportResponse.putAll(resultJsonObject);
                    return CommonResponse.success(reportResponse);
                }
            }.handle(response);
        } catch (Exception e) {
            log.error("report error:", e);
            throw new EtaxIncomeException(e);
        }
    }
}
