package com.sxc.etaxincome.domain.handler.transferparam;

import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Maps;
import com.sxc.etaxincome.domain.model.common.CommonRequestWrapper;
import com.sxc.etaxincome.domain.model.report.ApiConfig;
import com.sxc.etaxincome.domain.model.report.ApiParamMapping;
import com.sxc.etaxincome.domain.model.report.ReportRequestWrapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Slf4j
@Component
public class MappingReportTransferParamHandler implements IReportTransferParamHandler {
    @Override
    public void handle(ApiConfig apiConfig, CommonRequestWrapper requestCommonWrapper, ReportRequestWrapper reportRequestWrapper) {
        List<ApiParamMapping> apiParamMappingList = apiConfig.getApiParamMappingList();
        Map<String, String> apiParamMapping = apiParamMappingList.stream().collect(Collectors.toMap(ApiParamMapping::getApiParamName, ApiParamMapping::getEtaxParamName, (k1, k2) -> k1));
        LinkedHashMap<String, String> requestFormDataJsonObject = reportRequestWrapper.getFormData();
        LinkedHashMap<String, String> targetFormDataJsonObject = Maps.newLinkedHashMapWithExpectedSize(10);

        for (ApiParamMapping apiParamMappingEach : apiParamMappingList) {
            String dataKey = apiParamMappingEach.getApiParamName();
            log.info("dataKey:{}", dataKey);
            if (requestFormDataJsonObject.containsKey(dataKey)) {
                targetFormDataJsonObject.put(apiParamMapping.get(dataKey), requestFormDataJsonObject.get(dataKey));
            }
        }
        reportRequestWrapper.setFormData(targetFormDataJsonObject);
    }
}
