package com.sxc.etaxincome.domain.infrastructure.impl;

import com.alicp.jetcache.Cache;
import com.alicp.jetcache.CacheManager;
import com.alicp.jetcache.anno.CacheType;
import com.alicp.jetcache.template.QuickConfig;
import com.sxc.etaxincome.domain.infrastructure.ICacheService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.time.Duration;
import java.util.concurrent.TimeUnit;

/**
 * @author caosongqing
 * @date 2023/3/22
 * @description
 */
@Slf4j
@Service
public class CacheService implements ICacheService {

    public static final long DEFAULT_EXPIRED_TIME = 3600L;

    public static final String GX2022_AREA_LIST_KEY_PREFIX = "gx2022:areaList";

    public static final String DATA_PRIVILEGE_AREA_KEY_PREFIX = "erm:dataPrivilege:area:%s";

    public static final String DATA_PRIVILEGE_TAXNO_KEY_PREFIX = "erm:dataPrivilege:taxno:%s";

    public static final String DATA_PRIVILEGE_TAXCOUNT_KEY_PREFIX = "erm:dataPrivilege:taxcount:%s";

    public static final String GOODS_CATEGORY_KEY_PREFIX = "goods:category:%s";

    public static final String COOKIE_KEY_PREFIX = "cookie:%s";

    @Autowired
    private CacheManager cacheManager;

    private Cache<String, String> jetCache;

    @PostConstruct
    public void init() {
        QuickConfig qc = QuickConfig.newBuilder("cache:income-invoice:")
                .expire(Duration.ofSeconds(60 * 60L))
                .cacheType(CacheType.REMOTE)
                .syncLocal(true)
                .build();
        jetCache = cacheManager.getOrCreateCache(qc);
    }

    @Override
    public String get(String key) {
        return jetCache.get(key);
    }

    @Override
    public void put(String key, String value, long expiredTimeSeconds) {
        jetCache.put(key, value, expiredTimeSeconds, TimeUnit.SECONDS);
    }

    @Override
    public Cache<String ,String> getJetCache() {
        return this.jetCache;
    }

    @Override
    public boolean del(String key) {
        return jetCache.remove(key);
    }

}
